class Navplus {
    constructor() {
        this.navbar = document.getElementById('mainNavbar');
        this.navItems = document.getElementById('navItems');
        this.toggleIcon = document.getElementById('toggle-icon');
        this.defaultEasing = 'ease';
    }

    setAnim(animationClass) {
        this.navbar.classList.add(animationClass);
    }

    setAnimationEasing(easing) {
        this.navbar.style.transitionTimingFunction = easing;
    }

    setTheme(themeClass) {
        this.navbar.classList.remove('navplus-dark', 'navplus-light', 'navplus-blur');
        this.navbar.classList.add(themeClass);
    }

    setNavbarContent(content) {
        this.navItems.innerHTML = '';
        const ul = document.createElement('ul');

        content.forEach(item => {
            if (item.type === 'item') {
                const li = document.createElement('li');
                li.innerHTML = `<a href="${item.link}">${item.text}</a>`;
                ul.appendChild(li);
            } else if (item.type === 'drop') {
                const li = document.createElement('li');
                li.classList.add('nav-drop');
                li.innerHTML = `<a href="#">${item.text} <i class="fas fa-caret-down"></i></a>`;
                const subMenu = document.createElement('ul');
                item.items.forEach(sub => {
                    const subLi = document.createElement('li');
                    subLi.innerHTML = `<a href="${sub.link}">${sub.text}</a>`;
                    subMenu.appendChild(subLi);
                });
                li.appendChild(subMenu);
                ul.appendChild(li);
            }
        });

        this.navItems.appendChild(ul);
    }

    createNewDrop(text, items) {
        this.setNavbarContent([
            ...this.parseExistingContent(),
            { type: 'drop', text: text, items: items }
        ]);
    }

    updateDrop(text, newItems) {
        const content = this.parseExistingContent();
        content.forEach(item => {
            if (item.type === 'drop' && item.text === text) {
                item.items = newItems;
            }
        });
        this.setNavbarContent(content);
    }

    setToggleIcon(iconClass) {
        this.toggleIcon.className = iconClass;
    }

    setSecondToggleIcon(iconClass) {
        this.secondIcon = iconClass;

        document.getElementById('navbarToggle').addEventListener('click', () => {
            const isToggled = this.navItems.classList.toggle('active');
            this.toggleIcon.className = isToggled ? this.secondIcon : 'fas fa-bars';
        });
    }

    parseExistingContent() {
        return []; // Placeholder for advanced content parsing
    }
}
